import diffDay from '../utils/jsdate';
import { urls } from '../config/web.config';
import getAuthCode from '../utils/getAuthCode';

export const _initStateData = () => dispatch => {
  dispatch({ type: 'initStateData' });
};

export const setLeaveInfo = (key, value) => (dispatch, getState) => {
  const { leaveinfo } = getState().apply;
  leaveinfo[key] = value;
  if (key === 'beginTime' || key === 'endTime') {
    const { day, hours } = diffDay(leaveinfo.beginTime, leaveinfo.endTime);
    leaveinfo['day'] = day;
    leaveinfo['hours'] = hours;
  }
  dispatch({
    type: 'SET_LEAVEINFO',
    leaveinfo: { ...leaveinfo }
  });
};

export const submitLeaveApply = leaveinfo => async dispatch => {
  const code = await getAuthCode();
  const url = `${urls.leave}?code=${code}`;
  const result = await window.HWH5.fetchInternet(url, {
    method: 'post',
    body: JSON.stringify(leaveinfo),
    headers: { 'Content-Type': 'application/json' }
  }).then(res => res
    .json()
    .then(reply => reply)
    .catch(() => null));
  await dispatch({ type: 'SUBMIT_LEAVE', result });
  return result;
};

// 查询用户草稿
export const getApplyDraft = userId => async dispatch => {
  const code = await getAuthCode();
  const url = `${urls.myApplyDraft}?code=${code}`;
  const draftObj = await window.HWH5.fetchInternet(url).then(res => res
    .json()
    .then(reply => reply)
    .catch(error => {
      console.log(error);
      return null;
    }));
  if (draftObj === null || draftObj.length === 0) {
    const result = {};
    await dispatch({ type: 'REPORT_GET_DRAFT', leaveinfo: result });
    return result;
  } else {
    const reportInfo = draftObj[0] || {};
    if (reportInfo.beginTime && reportInfo.endTime) {
      const { day, hours } = diffDay(reportInfo.beginTime, reportInfo.endTime);
      reportInfo.day = day;
      reportInfo.hours = hours;
    }
    if (reportInfo.leaveType === null || reportInfo.leaveType === 'null') reportInfo.leaveType = '';
    if (reportInfo.leaderId === null || reportInfo.leaderId === 'null') reportInfo.leaderId = '';
    if (reportInfo.leaderName === null || reportInfo.leaderName === 'null') reportInfo.leaderName = '';
    await dispatch({ type: 'REPORT_GET_DRAFT', leaveinfo: reportInfo });
    return reportInfo;
  }
};
