import React from 'react';
import './index.less';
import PropTypes from 'prop-types';
import i18n from 'i18n';
import {
  Form, FormCell, CellFooter, CellBody, Radio 
} from '@wecode/react-weui';

export default class Dropdown extends React.Component {
  state = {
    dropDown: false,
    dropClass: ''
  };

  getApplyState(status) {
    switch (status) {
      case 0:
        return i18n.t('common:approval');
      case 1:
        return i18n.t('common:finish');
      case 2:
        return i18n.t('common:dismissText');
      case 3:
        return i18n.t('common:all');
      default:
        return '';
    }
  }

  handelDropDown() {
    const { dropDown } = this.state;
    this.setState({ dropDown: !dropDown }, () => {
      this.setState({ dropClass: dropDown ? 'dropdown_box__body_toggle' : '' });
    });
  }

  handleChangeValue(value) {
    const { dropDown } = this.state;
    const { onChange } = this.props;
    this.setState({ dropDown: !dropDown, dropClass: '' }, () => {
      onChange ? onChange(value) : () => {};
    });
  }

  render() {
    const {
      value, data, code, name 
    } = this.props;
    const { dropDown, dropClass } = this.state;
    return (
      <div className="dropdown_box__bg" style={{ display: `${data.length > 0 ? '' : 'none'}` }}>
        <div className="dropdown_box__header" onClick={e => this.handelDropDown()}>
          {data.length > 0 ? this.getApplyState(value) : ''}
          {dropDown ? (
            <i className="icon-12 icon-12-arrowBottom" />
          ) : (
            <i className="icon-12 icon-12-arrowTopRed" />
          )}
        </div>
        <div style={{ display: `${dropDown ? '' : 'none'}` }}>
          <div className="dropdown_box__body_bg" onClick={e => this.handelDropDown()} />
          <div className={`dropdown_box__body ${dropClass}`}>
            <Form radio>
              {data.map((param, index) => (
                <FormCell key={index} radio>
                  <CellBody style={{ color: value === param[code] ? '#F36F64' : '#333' }}>
                    {param[name]}
                  </CellBody>
                  <CellFooter>
                    <Radio
                      name="radio1"
                      value={param.key}
                      checked={value === param[code]}
                      onChange={() => this.handleChangeValue(param[code])}
                    />
                  </CellFooter>
                </FormCell>
              ))}
            </Form>
          </div>
        </div>
      </div>
    );
  }
}

Dropdown.propTypes = {
  value: PropTypes.number,
  code: PropTypes.string,
  name: PropTypes.string,
  data: PropTypes.array,
  onChange: PropTypes.func
};
