import React from 'react';
import { bindActionCreators } from 'redux';
import { connect } from 'react-redux';
import {
  Cells,
  Cell,
  CellBody,
  CellFooter,
  Picker,
  Form,
  Button,
  FormCell,
  TextArea,
  CellsTitle,
  Input,
  ActionSheet,
  Grid
} from '@wecode/react-weui';
import LightBox from 'react-image-lightbox';
import moment from 'moment';
import PropTypes from 'prop-types';
import i18n from 'i18n';
import * as global from '../../actions/global';
import * as apply from '../../actions/apply';
import './index.less';
import userSrc from './images/defaultface.png';
import DateTimeLocal from '../../components/DateTimeLocal';
import { urls } from '../../config/web.config';
import rightArrow from './images/rightArrow.png';
import redStar from './images/redStar.png';
import addUserSrc from './images/adduser.png';
import picdel from './images/picdel.png';

@connect(
  state => ({ ...state.apply, ...state.global }),
  dispatch => bindActionCreators({ ...apply, ...global }, dispatch)
)
export default class Apply extends React.Component {
  state = {
    pickerShow: false,
    bottomDialog: { // 选择弹框对象
      bool: false,
      menus: [{ label: '', onClick: null }, { label: '', onClick: null }]
    },
    isOpen: false,
    photoIndex: 0
  }

  pickerGroup = [
    {
      items: [
        {
          label: i18n.t('common:casualLeave') 
        },
        {
          label: i18n.t('common:sickLeave') 
        },
        {
          label: i18n.t('common:annualLeave') 
        },
        {
          label: i18n.t('common:replacementLeave') 
        },
        {
          label: i18n.t('common:others') 
        }
      ]
    }
  ]

  submiting = false;

  async componentWillMount() {
    const { 
      _initStateData, getUserInfo 
    } = this.props;
    this.getPlatform();
    _initStateData();
    window.HWH5.setNavigationBarButtons && window.HWH5.setNavigationBarButtons([
      {
        iconPath: '',
        text: '',
        func: () => { }
      }
    ]);

    window.HWH5.navTitle({ title: i18n.t('common:appName') });
    await getUserInfo();
    await this.getMyDraft();
  }

  // 组件加载完成
  componentDidMount() {
    window.HWH5.addEventListener({ type: 'back', func: this.backFunction });
  }

  // 组件即将销毁
  componentWillUnmount() {
    window.HWH5.removeEventListener({ type: 'back', func: this.backFunction });
  }

  getPlatform = ()=>{
    HWH5.deviceInfo().then((data) => {
      HWH5.platform = data.osType;
    }).catch((error)=>{
      console.log(error);
      HWH5.platform = 'android';
    });
  }

  getMyDraft = ()=>{
    const { getApplyDraft, userInfo } = this.props;
    window.HWH5.loading({ status: true }); // 加载中图标
    window.HWH5.networkStatus().then(async data => {
      if (this.isNotEmpty(data) && data.status) {
        const isDraft = await getApplyDraft(userInfo.uid); // 查询用户的草稿信息
        window.HWH5.loading({ status: false });
        if (isDraft === null) {
          window.HWH5.toast({ msg: i18n.t('common:appName'), type: 'n' });
        }
      } else {
        window.HWH5.loading({ status: false });
        window.HWH5.toast({ msg: i18n.t('common:netWorkUnnormal'), type: 'n' });
      }
    }).catch((error)=>{
      console.log(error);
      window.HWH5.loading({ status: false });
      window.HWH5.toast({ msg: i18n.t('common:netWorkUnnormal'), type: 'n' });
    });
  }

  // 选择附件: 图片/拍摄
  onImagePicker = (flag) => {
    const { setLeaveInfo } = this.props;
    const menus = [{ label: '', onClick: null }, { label: '', onClick: null }];
    const { bottomDialog } = this.state;
    bottomDialog.bool = false;
    bottomDialog.menus = menus;
    this.setState({ bottomDialog });
    window.HWH5.imagePicker({ flag }).then(async (data)=>{
      const { leaveinfo } = this.props;
      const { filePathArr = [] } = leaveinfo;
      if (data.length !== 0) {
        data.forEach(item => {
          const itemoObj = {};
          itemoObj.name = item.substr(item.lastIndexOf('/') + 1);
          itemoObj.path = item;
          filePathArr.push(itemoObj);
        });
        await setLeaveInfo('filePathArr', filePathArr);
      }
    }).catch((error)=>{
      console.log('HWH5 API：访问相册异常 flag=' + flag, error);
    });
  }

  // 点击后退
  backFunction = () => {
    const { leaveinfo = {} } = this.props;
    if (this.isNotEmpty(leaveinfo.leaveReason)) {
      this.saveDraft();
    } 
    return true;
  }

  // 动态展示用户头像
  showFaceImg = (userId) => {
    const imgSrc = this.isNotEmpty(userId) ? (userId === 'add' ? addUserSrc : urls.headIcon.replace('{0}', userId)) : userSrc;
    if (userId === 'add') return <img src={imgSrc} onError={(img) => { img.target.src = userSrc; }} alt="" />;
    return <img src={imgSrc} onError={(img) => { img.target.src = userSrc; }} alt="" onClick={this.handleApproverInfo} />;
  }

  // 判断是否为空
  isNotEmpty = (value) => {
    if (typeof value !== 'undefined' && value !== null && value !== '') {
      return true;
    }
    return false;
  }

  handleApproverInfo = () => {
    const { setLeaveInfo, userInfo } = this.props;
    const param = {
      bundleName: '', // 必传，可以为空
      needCallback: true, // 必传，布尔类型。是否需要回调，将返回选中的联系人相关信息
      isSingleSelection: true, // 可选，是否单选，默认false
      mode: 0, // 可选，选择模式 0，包含选择联系人的基本信息
      dataSourceType: 1, // 可选, 我的内部联系人 1
      supportPortals: 1, // 选人组件顶部支持的入口定义：我的联系人 1
      fixedFlag: 2 // 特殊场景标志位：1 已选中不可操作的人员显示在顶部头像展示栏；2 返回数据包含已选中不可操作的人员
    };
    window.HWH5.selectContacts(param).then(async result => {
      if (result && result.data) {
        const id = result.data[0].w3account;
        if (id === userInfo.uid) {
          window.HWH5.toast({ msg: i18n.t('common:approverLimit'), type: 'n' });
          return false;
        } 
        const name = i18n.language === 'zh_CN' ? (result.data[0].chineseName || result.data[0].englishName) : (result.data[0].englishName || result.data[0].chineseName);
        await setLeaveInfo('leaderId', id);
        await setLeaveInfo('leaderName', name);
        return true;
      }
      return false;
    }).catch(() => {
      // window.HWH5.toast({ msg: i18n.t('common:getContractFail'), type: 'n' });
    });
  }

  hanleRemoveFiles = async (index) => {
    const { leaveinfo, setLeaveInfo } = this.props;
    const { filePathArr = [] } = leaveinfo;
    filePathArr.splice(index, 1);
    await setLeaveInfo('filePathArr', filePathArr);
  }

  // 提交
  commitLeaveApply = async () => {
    if (this.submiting) return false;
    const { 
      leaveinfo = {}, submitLeaveApply, history, _initStateData 
    } = this.props; // history

    if (!leaveinfo.beginTime || !leaveinfo.endTime) {
      return window.HWH5.toast({ msg: i18n.t('common:timeUncorrect'), type: 'n' });
    }
    if (moment(leaveinfo.endTime).isSameOrBefore(moment(leaveinfo.beginTime))) {
      return window.HWH5.toast({ msg: i18n.t('common:timeUncorrect'), type: 'n' });
    }
    leaveinfo.isDraft = 0;
    this.submiting = true;
    const reply = await submitLeaveApply(leaveinfo);
    if (reply && reply.result === 'success') {
      _initStateData();
      this.submiting = false;
      return history.goBack();
    }
    this.submiting = false;
    return window.HWH5.toast({ msg: i18n.t('common:submitFail'), type: 'n' });
  }

  // 保存草稿
  saveDraft = async ()=>{
    const { 
      leaveinfo = {}, submitLeaveApply, userInfo 
    } = this.props;
    leaveinfo.isDraft = 1;
    if (!leaveinfo.beginTime || leaveinfo.beginTime === 'null') leaveinfo.beginTime = '';
    if (!leaveinfo.endTime || leaveinfo.endTime === 'null') leaveinfo.endTime = '';
    leaveinfo.uid = userInfo.uid;
    leaveinfo.userName = userInfo.userNameZH || userInfo.userNameEN;
    const reply = await submitLeaveApply(leaveinfo);
    if (reply && reply.result !== 'success') {
      window.HWH5.toast({ msg: i18n.t('common:saveDraftFail'), type: 'n' });
    }
  }

  // 底部选择框组件开关, type: img=上传文件, save=保存草稿, off=关闭弹框
  bottomDialogSwitch = (type) => {
    const { bottomDialog } = this.state;
    bottomDialog.bool = type !== 'off';
    let menus = [{ label: '', onClick: null }, { label: '', onClick: null }];
    if (type === 'img') menus = [{ label: '图片', onClick: ()=> this.onImagePicker(1) }, { label: '拍摄', onClick: ()=> this.onImagePicker(2) }];
    if (type === 'save') menus = [{ label: '保存为草稿', onClick: ()=> this.saveDraft() }, { label: '不保存退出', onClick: ()=> this.backoff() }];
    bottomDialog.menus = menus;
    this.setState({ bottomDialog });
  }

  // 不保存退出
  backoff = ()=>{
    window.HWH5.removeEventListener({ type: 'back', func: this.backFunction });
    const { history, _initStateData } = this.props;
    _initStateData(); 
    history.goBack();
  }

  onDeleteApprove = async ()=>{
    const { setLeaveInfo } = this.props;
    await setLeaveInfo('leaderId', '');
    await setLeaveInfo('leaderName', '');
  }

  showImageZoomVier = (index)=>{
    this.setState({
      isOpen: true,
      photoIndex: index
    });
  }

  // 选择日期回调
  onSetDate = (key, value) => {
    const { setLeaveInfo } = this.props;
    setLeaveInfo(key, value);
  }

  // 失去焦点
  onNoneFocus = () => {
    this.refNoneFacus.focus();
  }

  render() {
    const { 
      leaveinfo = {}, setLeaveInfo 
    } = this.props; // pickerGroup
    const { 
      bottomDialog, pickerShow, isOpen, photoIndex 
    } = this.state;
    return (
      <div className="Apply app_apply_bg">
        <div>
          <div onClick={this.onNoneFocus.bind(this)}>  
            <Cells>
              <Cell className="commonCell">
                <img src={redStar} alt="" className="redStar" />
                <CellBody className="header">{i18n.t('common:leaveTypes')}</CellBody>
                <CellFooter>
                  <Input
                    style={{ textAlign: 'right' }}
                    type="text"
                    value={leaveinfo.leaveType}
                    onClick={() => {
                      document.activeElement.blur();
                      this.setState({ pickerShow: true });
                    }}
                    placeholder={i18n.t('common:options')}
                    readOnly
                    lang={{ 'leftBtn': i18n.t('common:cancel'), 'rightBtn': i18n.t('common:ok') }}
                  />
                </CellFooter>
                <img src={rightArrow} alt="" style={{ width: 16, height: 16, marginLeft: 3 }} />
              </Cell>
            </Cells>
            <Cells>
              <Cell className="commonCell time">
                <img src={redStar} alt="" className="redStar" />
                <CellBody className="header">{i18n.t('common:startTime')}</CellBody>
                <CellFooter>
                  <DateTimeLocal
                    type="beginTime"
                    title={i18n.t('common:startTime')}
                    value={leaveinfo.beginTime}
                    onChange={this.onSetDate.bind(this)}
                  />
                </CellFooter>
                <img src={rightArrow} alt="" style={{ width: 16, height: 16, marginLeft: 3 }} />
              </Cell>
              <Cell className="commonCell time">
                <img src={redStar} alt="" className="redStar" />
                <CellBody className="header">{i18n.t('common:endTime')}</CellBody>
                <CellFooter>
                  <DateTimeLocal
                    type="endTime"
                    title={i18n.t('common:endTime')}
                    value={leaveinfo.endTime}
                    onChange={this.onSetDate.bind(this)}
                  />
                </CellFooter>
                <img src={rightArrow} alt="" style={{ width: 16, height: 16, marginLeft: 3 }} />
              </Cell>
              {/* <div style={showErrorStyle}>{i18n.t('common:endTimeLimited')}</div> */}
              <Cell style={{ paddingTop: 10, paddingBottom: 10 }}>
                <img src={redStar} alt="" className="redStar" />
                <CellBody className="header">{i18n.t('common:intervalTime')}</CellBody>
                <CellFooter>
                  <span className="day_">{leaveinfo.day || 0}</span>
                  <span className="day">{i18n.t('common:days')}</span>
                  <span className="hours_">{leaveinfo.hours || 0}</span>
                  <span className="hours">{i18n.t('common:hours')}</span>
                </CellFooter>
              </Cell>
            </Cells>
            <Cells>
              <CellsTitle className="spaciess">
                <div className="flex">
                  <img src={redStar} alt="" className="redStar" />
                  <div className="header" style={{ lineHeight: 1.5 }}>{i18n.t('common:reason')}</div>
                </div>
              </CellsTitle>
              <Form style={{ marginTop: 0 }}>
                <FormCell className="inputContent">
                  <CellBody>
                    <TextArea
                      placeholder={i18n.t('common:description')}
                      rows="3"
                      maxLength="1000"
                      value={leaveinfo.leaveReason}
                      onChange={val => setLeaveInfo('leaveReason', val.target.value)}
                    />
                  </CellBody>
                </FormCell>
              </Form>
            </Cells>
            <Cells className="approver detail__icon-box">
              <Cell>
                <img src={redStar} alt="" className="redStar" />
                <CellBody className="header">{i18n.t('common:approvalSettings')}</CellBody>
              </Cell>
              <Form style={{ overflow: 'initial' }}>
                <FormCell style={{ padding: '0 20px' }}>
                  <CellBody>
                    <div>
                      { !this.isNotEmpty(leaveinfo.leaderName) && <Grid icon={this.showFaceImg('add')} label="&nbsp;" onClick={this.handleApproverInfo} /> }
                      { this.isNotEmpty(leaveinfo.leaderId) 
                      && (
                        <Grid 
                          icon={this.showFaceImg(leaveinfo.leaderId)}
                          label={leaveinfo.leaderName}
                        >
                          <img src={picdel} alt="" className="picDeleteBtn" onClick={this.onDeleteApprove} />
                        </Grid>) }
                    </div>
                  </CellBody>
                </FormCell>
              </Form>
            </Cells>
          </div>
          <input type="radio" className="none-input" ref={(el) => { this.refNoneFacus = el; }} />
          <div className="bottomBtn">
            <Button onClick={this.commitLeaveApply} className=""> 
              {i18n.t('common:commit')}
            </Button>
          </div> 
        </div>
        <Picker
          onChange={(selected) => {
            let value = '';
            selected.forEach((s, i) => {
              value = this.pickerGroup[i].items[s].label;
            });
            setLeaveInfo('leaveType', value);
            this.setState({ pickerShow: false });
          }}
          groups={this.pickerGroup}
          show={pickerShow}
          onCancel={() => {
            this.setState({ pickerShow: false });
          }}
          defaultSelect={[0]}
          lang={{ 'leftBtn': i18n.t('common:cancel'), 'rightBtn': i18n.t('common:ok') }}
        />
        <ActionSheet
          type="ios"
          style={{ color: '#333' }}
          show={bottomDialog.bool}
          menus={bottomDialog.menus}
          actions={[{ label: i18n.t('common:cancel'), onClick: ()=> this.bottomDialogSwitch('off') }]}
          onRequestClose={()=>this.bottomDialogSwitch('off')}
        />
        {isOpen && (
          <LightBox
            mainSrc={leaveinfo.filePathArr[photoIndex].path}
            nextSrc={leaveinfo.filePathArr[(photoIndex + 1) % leaveinfo.filePathArr.length].path}
            prevSrc={leaveinfo.filePathArr[
              (photoIndex + leaveinfo.filePathArr.length - 1) % leaveinfo.filePathArr.length
            ].path}
            onCloseRequest={()=>{ 
              this.setState({ isOpen: false }); 
            }}
            onMovePrevRequest={()=>{
              this.setState({
                photoIndex: 
                (photoIndex + leaveinfo.filePathArr.length - 1) % leaveinfo.filePathArr.length
              });
            }}
            onMoveNextRequest={()=>{
              this.setState({
                photoIndex: (photoIndex + 1) % leaveinfo.filePathArr.length
              });
            }}
          />
        )}
      </div>
    );
  }
}

Apply.propTypes = {
  leaveinfo: PropTypes.object,
  history: PropTypes.object,
  setLeaveInfo: PropTypes.func,
  getUserInfo: PropTypes.func,
  userInfo: PropTypes.object,
  _initStateData: PropTypes.func,
  submitLeaveApply: PropTypes.func, // 提交我的请假申请
  getApplyDraft: PropTypes.func // 获取我的请假申请草稿
};
