import React from 'react';
import { bindActionCreators } from 'redux';
import { connect } from 'react-redux';
import PropTypes from 'prop-types';
import {
  Cells,
  Cell,
  CellBody,
  CellFooter,
  Form,
  Button,
  FormCell,
  TextArea,
  // CellHeader,
  CellsTitle,
  Dialog,
  ButtonArea,
  Tab,
  TabBody,
  TabBarItem,
  TabBar
} from '@wecode/react-weui';
import i18n from 'i18n';
import moment from 'moment';
// import createHistory from 'history/createBrowserHistory';
import * as home from '../../actions/home';
import * as global from '../../actions/global';
import * as detail from '../../actions/detail';
import DiffDay from '../../utils/jsdate';
import defaultface from '../Apply/images/defaultface.png';
// import deleteSrc from '../Apply/images/delete.png';
import IconBox from '../../components/IconBox';
import './index.less';
import { urls } from '../../config/web.config';
import '../Home/index.less';
import redStar from '../Apply/images/redStar.png';

@connect(
  state => ({ ...state.detail, ...state.home, ...state.global }),
  dispatch => bindActionCreators({ ...home, ...global, ...detail }, dispatch)
)
export default class Detail extends React.Component {
  state = {
    desc: '',
    showDialog: false
  };

  async componentWillMount() {
    const { getUserInfo, getFetchDetail } = this.props;
    window.HWH5.setNavigationBarButtons && window.HWH5.setNavigationBarButtons([
      {
        iconPath: '',
        text: '',
        func: () => {
        }
      }
    ]);
    window.HWH5.loading({ status: true });
    window.HWH5.navTitle({ title: i18n.t('common:appName') });
    await getUserInfo();
    const { match } = this.props;
    const { params = {} } = match;
    getFetchDetail(params.detailId);
    window.HWH5.loading({ status: false });
  }

  handleApprove = async result => {
    const { 
      userInfo, setApproval, history, match 
    } = this.props;
    const { params = {} } = match;
    const { desc } = this.state;
    const param = {
      approveResult: result,
      approveComment: desc,
      approveUserId: userInfo.uid,
      id: params.detailId
    };
    const res = await setApproval(param);
    if (res && res.result === 'success') {
      history.goBack();
    }
  };

  // 判断是否为空
  isNotEmpty = (value) => {
    if (typeof value !== 'undefined' && value !== null && value !== '') {
      return true;
    }
    return false;
  }

  handleFaceImg = (userId, userName) => {
    if (this.isNotEmpty(userId) && this.isNotEmpty(userName)) {
      const headerPath = urls.headIcon.replace('{0}', userId);
      return headerPath;
    }
    return defaultface;
  }

  render() {
    const {
      leaveDetail
    } = this.props;
    const { showDialog, desc } = this.state;
    const { day, hours } = DiffDay(leaveDetail.beginTime, leaveDetail.endTime);
    const { match } = this.props;
    const { params = {} } = match;
    return (
      <div className="App app_detail_bg">
        <Tab>
          <TabBody>
            <Cells>
              <Cell style={{ paddingTop: 12, paddingBottom: 12 }}>
                <img src={redStar} alt="" className="redStar" />
                <CellBody className="header">{i18n.t('common:leaveTypes')}</CellBody>
                <CellFooter>
                  <span>{leaveDetail.leaveType}</span>
                </CellFooter>
              </Cell>
            </Cells>
            <Cells>
              <Cell className="commonCell">
                <img src={redStar} alt="" className="redStar" />
                <CellBody className="header">{i18n.t('common:startTime')}</CellBody>
                <CellFooter>
                  <span>
                    {moment(leaveDetail.beginTime).format('YYYY-MM-DD HH:mm')}
                  </span>
                </CellFooter>
              </Cell>
              <Cell className="commonCell">
                <img src={redStar} alt="" className="redStar" />
                <CellBody className="header">{i18n.t('common:endTime')}</CellBody>
                <CellFooter>
                  <span>
                    {moment(leaveDetail.endTime).format('YYYY-MM-DD HH:mm')}
                  </span>
                </CellFooter>
              </Cell>
              <Cell className="commonCell">
                <img src={redStar} alt="" className="redStar" />
                <CellBody className="header">{i18n.t('common:intervalTime')}</CellBody>
                <CellFooter>
                  <span>{day}&nbsp;</span>
                  {i18n.t('common:days')} 
                  <span>{hours}&nbsp;</span>
                  {i18n.t('common:hours')}
                </CellFooter>
              </Cell>
            </Cells>
            <Cells>
              <CellsTitle style={{ fontSize: '16px', color: '#333', marginBottom: '0px' }}>
                <div className="flex">
                  <img src={redStar} alt="" className="redStar" />
                  <div className="header" style={{ lineHeight: 1.5 }}>{i18n.t('common:reason')}</div>
                </div>
              </CellsTitle>
              <Form>
                <FormCell style={{ paddingTop: 0 }}>
                  <CellBody>
                    <div className="inputContent">{leaveDetail.leaveReason}</div>
                  </CellBody>
                </FormCell>
              </Form>
            </Cells>

            {/* <Cells className="attachmentContainer">
              <Cell list>
                <CellBody>{i18n.t('common:attachment')}</CellBody>
              </Cell>
              <Form className="attatchfiles">
                {attachArr.map((item, index) => (
                  <FormCell key={index}>
                    <CellHeader>
                      <img
                        alt=""
                        src={deleteSrc}
                        style={{
                          display: 'block',
                          width: '24px',
                          marginRight: '14px'
                        }}
                      />
                    </CellHeader>
                    <CellBody>{item.name}</CellBody>
                  </FormCell>
                ))}
              </Form>
            </Cells> */}

            <Cells className="detail__icon-box">
              <Cell>
                <img src={redStar} alt="" className="redStar" />
                <CellBody className="header">{i18n.t('common:approvalProcess')}</CellBody>
              </Cell>
              <Cell className="iconBox">
                <IconBox
                  clsName="box"
                  imgstr={(
                    <img
                      src={this.handleFaceImg(leaveDetail.applyUserId, leaveDetail.userName)}
                      alt=""
                      onError={(e) => {
                        e.target.src = defaultface;
                      }}
                    />)}
                  title={leaveDetail.userName}
                />
                <IconBox clsName="splitImg" />
                <IconBox
                  clsName="box"
                  imgstr={(
                    <img
                      src={this.handleFaceImg(leaveDetail.leaderId, leaveDetail.leaderName)}
                      alt=""
                      onError={(e) => {
                        e.target.src = defaultface;
                      }}
                    />)}
                  title={leaveDetail.leaderName}
                />
              </Cell>
            </Cells>
            {
              leaveDetail.stateKey === 2 ? (
                <Cells>
                  <CellsTitle style={{
                    fontSize: '16px',
                    color: '#333',
                    marginBottom: '0px'
                  }}
                  >{i18n.t('common:dismissReason')}
                  </CellsTitle>
                  <Form>
                    <FormCell>
                      <CellBody>
                        <div style={{ fontSize: '14px' }}>{leaveDetail.approveComment}</div>
                      </CellBody>
                    </FormCell>
                  </Form>
                </Cells>
              ) : ''
            }
          </TabBody>
          <TabBar>
            <TabBarItem>
              {params.type === '0' ? (
                <Button disabled>{leaveDetail.stateValue}</Button>
              ) : (
                <ButtonArea direction="horizontal">
                  <Button
                    style={{ borderRadius: 2 }}
                    onClick={() =>this.setState({ desc: i18n.t('common:agree') }, () =>this.handleApprove(1))
                    }
                  >
                    {i18n.t('common:agree')}
                  </Button>
                  <Button
                    style={{ borderRadius: 2 }}
                    type="warn" 
                    onClick={() => { this.setState({ showDialog: true, desc: '' }); }}
                  >
                    {i18n.t('common:dismiss')}
                  </Button>
                </ButtonArea>
              )}
            </TabBarItem>
          </TabBar>
        </Tab>
        <Dialog
          className="dismiss-dialog"
          title={i18n.t('common:dismissApproval')}
          show={showDialog}
          buttons={[
            {
              type: 'default',
              label: i18n.t('common:cancel'),
              onClick: () => this.setState({ showDialog: false })
            },
            {
              type: 'default',
              label: i18n.t('common:ok'),
              onClick: () => this.handleApprove(2)
            }
          ]}
        >
          <Cells>
            <FormCell className="textareaWarp">
              <TextArea
                placeholder={i18n.t('common:approvalDescription')}
                rows="3"
                showCounter={false}
                onChange={e => this.setState({ desc: e.target.value })}
                value={desc}
              />
            </FormCell>
          </Cells>
        </Dialog>
      </div>
    );
  }
}

Detail.propTypes = {
  getUserInfo: PropTypes.func,
  userInfo: PropTypes.object,
  // myDetail: PropTypes.object,
  // fileNameArr: PropTypes.array,
  // filePathArr: PropTypes.array,
  getFetchDetail: PropTypes.func,
  leaveDetail: PropTypes.object,
  setApproval: PropTypes.func,
  history: PropTypes.object,
  match: PropTypes.object // url参数
};
