import React from 'react';
import { bindActionCreators } from 'redux';
import { connect } from 'react-redux';
import PropTypes from 'prop-types';
import {
  Tab, NavBar, TabBody, NavBarItem, DropDown 
} from '@wecode/react-weui';
import i18n from 'i18n';
import * as home from '../../actions/home';
import * as global from '../../actions/global';
import './index.less';
import ListBox from '../../components/ListBox';
import addPress from './images/addPress.png';

@connect(
  state => ({ ...state.home, ...state.global }),
  dispatch => bindActionCreators({ ...home, ...global }, dispatch)
)
export default class Home extends React.Component {
  state = {
    value: 3
  };

  async componentWillMount() {
    window.HWH5.navTitle({ title: i18n.t('common:appName') });
    const pathlist = addPress.split('assets');
    const {
      history,
      getUserInfo,
      getLeaveMyList,
      getApproveList,
      firstLoad,
      changeStatus,
      changeTab
    } = this.props;
    const { value } = this.state;
    window.HWH5.loading({ status: true });
    window.HWH5.setNavigationBarButtons && window.HWH5.setNavigationBarButtons([
      {
        iconPath: `assets${pathlist[1]}`,
        text: i18n.t('common:createNew'),
        func: () => {
          setTimeout(() => {
            history.push('/apply');
          }, 100);
        }
      }
    ]);
    const userInfo = await getUserInfo();
    const approveList = await getApproveList(userInfo.uid);
    if (approveList.data && approveList.data.length > 0 && firstLoad) {
      changeTab(1);
      changeStatus(false);
    }
    await getLeaveMyList(userInfo.uid, value);
    window.HWH5.loading({ status: false });
  }

  changeValue = value => {
    const { userInfo = {}, getLeaveMyList } = this.props;
    window.HWH5.loading({ status: true });
    this.setState({ value }, async () => {
      await getLeaveMyList(userInfo.uid, value);
      window.HWH5.loading({ status: false });
    });
  };

  handleMyDetail = async id => {
    const { tab } = this.props;
    const { history } = this.props;
    history.push(`/detail/${tab}/${id}`);
  };

  render() {
    const dataList = [
      { value: 3, label: i18n.t('common:all') },
      { value: 0, label: i18n.t('common:approval') },
      { value: 1, label: i18n.t('common:finish') },
      { value: 2, label: i18n.t('common:dismissText') }
    ];
    const { myLeaveList = [], myApproveList = [] } = this.props;
    const { value } = this.state;
    const { tab, changeTab } = this.props;
    return (
      <div className="Home">
        <Tab>
          <NavBar className="app-tab__font" style={{ height: '7vh', lineHeight: '7vh' }}>
            <NavBarItem
              style={{ height: '7vh', lineHeight: '7vh' }}
              active={tab === 0}
              onClick={e => changeTab(0)}
            >
              <span className={tab === 0 ? 'app-tab__font_active_on' : 'app-tab__font_active_off'}>
                {i18n.t('common:myApply')}
              </span>
            </NavBarItem>
            <NavBarItem
              style={{ height: '7vh', lineHeight: '7vh' }}
              active={tab === 1}
              onClick={e => changeTab(1)}
            >
              <span className={tab === 1 ? 'app-tab__font_active_on' : 'app-tab__font_active_off'}>
                {`${i18n.t('common:waitMyArrove')}(${myApproveList.length})`}
              </span>
            </NavBarItem>
          </NavBar>
          <TabBody style={{ height: '100vh' }}>
            <div
              style={{
                width: '100%',
                display: tab === 0 ? null : 'none'
              }}
            >
              <DropDown
                key="dropdown"
                value={value}
                radioName="radio"
                dataSource={dataList}
                onChange={value => this.changeValue(value)}
              />
            </div>
            <div>
              <ListBox
                key="1"
                tab={tab}
                data={tab === 0 ? myLeaveList : myApproveList}
                onClick={e => this.handleMyDetail(e)}
              />
            </div>
          </TabBody>
        </Tab>
      </div>
    );
  }
}

Home.propTypes = {
  history: PropTypes.object,
  firstLoad: PropTypes.bool,
  changeStatus: PropTypes.func,
  tab: PropTypes.number,
  changeTab: PropTypes.func,
  userInfo: PropTypes.object,
  myLeaveList: PropTypes.array,
  myApproveList: PropTypes.array,
  getUserInfo: PropTypes.func,
  getLeaveMyList: PropTypes.func,
  getApproveList: PropTypes.func
};
