package com.cloudlink.open.controller;

import java.util.ArrayList;
import java.util.List;

import javax.servlet.http.HttpServletRequest;

import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;

import com.cloudlink.open.bo.LeaveBO;
import com.cloudlink.open.common.Constant;
import com.cloudlink.open.common.ResultVO;
import com.cloudlink.open.common.User;
import com.cloudlink.open.service.LeaveService;
import com.cloudlink.open.util.ErrorCodeUtil;
import com.cloudlink.open.vo.LeaveApproveVO;
import com.cloudlink.open.vo.LeaveVO;

/**
 * controller层
 * @author Administrator
 *
 */
@RestController
@RequestMapping("/wecode/demo/v1")
@Component
public class LeaveController {
	@Autowired
	private LeaveService leaveService;

	/**
	 * 申请及修改请假
	 * 
	 * @param leaveVo
	 * @return
	 */
	@RequestMapping(value = { "/leave" }, method = { RequestMethod.POST })
	public ResultVO applyLeave(HttpServletRequest request, @RequestBody LeaveVO leaveVo) {
		ResultVO result = new ResultVO();
		result.setResult(Constant.OPERATE_SUCCESS);
		User user = (User) request.getSession().getAttribute(Constant.USER_SESSION_KEY);
		leaveVo.setApplyUserId(user.getUserId());
		leaveVo.setUserName(user.getUserName());
		try {
			if (StringUtils.isBlank(leaveVo.getBeginTime())) {
				result.setResult(Constant.OPERATE_FAIL);
				result.setErrorCode(ErrorCodeUtil.LEAVE_PARMA_CODE);
				result.setErrorMessage(ErrorCodeUtil.LEAVE_BEGIN_TIME_MESSAGE);
				return result;
			}
			if (StringUtils.isBlank(leaveVo.getEndTime())) {
				result.setResult(Constant.OPERATE_FAIL);
				result.setErrorCode(ErrorCodeUtil.LEAVE_PARMA_CODE);
				result.setErrorMessage(ErrorCodeUtil.LEAVE_ENDTIME_TIME_MESSAGE);
				return result;
			}
			/**
			 * 其它必填业务参数判断
			 */
			LeaveBO bo = new LeaveBO();
			BeanUtils.copyProperties(leaveVo, bo);
			leaveService.saveLeave(bo);
		} catch (Exception e) {
			result.setResult(Constant.OPERATE_FAIL);
			result.setErrorMessage(e.getMessage());
		}

		return result;
	}

	/**
	 * 查询个人请假列表
	 * @param request
	 * @param leaveState 请假单状态
	 * @return
	 */
	@RequestMapping(value = { "/leaves" }, method = { RequestMethod.GET })
	public List<LeaveVO> getMyLeaves(HttpServletRequest request, @RequestParam("leaveState") int leaveState) {
		List<LeaveVO> voList = new ArrayList<LeaveVO>();
		User user = (User) request.getSession().getAttribute(Constant.USER_SESSION_KEY);
		List<LeaveBO> boList = this.leaveService.getMyList(user.getUserId(), leaveState);
		for (LeaveBO bo : boList) {
			LeaveVO vo = new LeaveVO();
			BeanUtils.copyProperties(bo, vo);
			voList.add(vo);
		}
		return voList;

	}

	/**
	 * 查询请假单详情
	 * 
	 * @param id 请假单ID
	 * @return
	 */
	@RequestMapping(value = { "/leave/{id}" }, method = { RequestMethod.GET })
	public LeaveVO leaveDetail(@PathVariable(value = "id") String id) {
		LeaveVO vo = new LeaveVO();
		LeaveBO bo = this.leaveService.getLeave(id);
		if (bo != null) {
			BeanUtils.copyProperties(bo, vo);
		}
		return vo;

	}
	
	/**
	 * 查询审批列表
	 * @param request
	 * @param leaveState
	 * @return
	 */
	@RequestMapping(value = { "/approval/leaves" }, method = { RequestMethod.GET })
	public List<LeaveVO> approveLeaveList(HttpServletRequest request, @RequestParam("leaveState") int leaveState) {
		List<LeaveVO> voList = new ArrayList<LeaveVO>();
		User user = (User) request.getSession().getAttribute(Constant.USER_SESSION_KEY);
		List<LeaveBO> boList = this.leaveService.getApproveList(user.getUserId(), leaveState);
		for (LeaveBO bo : boList) {
			LeaveVO vo = new LeaveVO();
			BeanUtils.copyProperties(bo, vo);
			voList.add(vo);
		}
		return voList;
	}

	/**
	 * 审批请假电子流
	 * @param leaveVo
	 * @return
	 */
	@RequestMapping(value = { "/leave/approval" }, method = { RequestMethod.POST })
	public ResultVO approveLeave(@RequestBody LeaveApproveVO leaveVo) {
		ResultVO result = new ResultVO();
		result.setResult(Constant.OPERATE_SUCCESS);
		this.leaveService.updateLeave(leaveVo);
		return result;
	}

	/**
	 * 查询草稿
	 * @param request
	 * @return
	 */
	@RequestMapping(value = { "/draft/leaves" }, method = { RequestMethod.GET })
	public List<LeaveVO> getDraftLeaves(HttpServletRequest request) {
		List<LeaveVO> voList = new ArrayList<LeaveVO>();
		User user = (User) request.getSession().getAttribute(Constant.USER_SESSION_KEY);
		List<LeaveBO> boList = this.leaveService.getDraftLeaveList(user.getUserId());
		for (LeaveBO bo : boList) {
			LeaveVO vo = new LeaveVO();
			BeanUtils.copyProperties(bo, vo);
			voList.add(vo);
		}
		return voList;
	}
}
