package com.cloudlink.open.filter;

import java.io.IOException;

import javax.servlet.Filter;
import javax.servlet.FilterChain;
import javax.servlet.FilterConfig;
import javax.servlet.ServletException;
import javax.servlet.ServletRequest;
import javax.servlet.ServletResponse;
import javax.servlet.annotation.WebFilter;
import javax.servlet.http.HttpServletRequest;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;

import com.cloudlink.open.common.Constant;
import com.cloudlink.open.common.User;
import com.cloudlink.open.util.FreeAccessHelper;

@WebFilter(urlPatterns = "/wecode/demo/*", filterName = "authFilter")
public class AuthFilter implements Filter {
	private static final Logger logger = LoggerFactory.getLogger(AuthFilter.class);
	@Autowired
	private FreeAccessHelper freeAccessHelper;

	public void init(FilterConfig filterConfig) throws ServletException {

	}

	public void doFilter(ServletRequest servletRequest, ServletResponse servletResponse, FilterChain filterChain)
			throws IOException, ServletException {

		HttpServletRequest httpRequest = (HttpServletRequest) servletRequest;
		User user = (User) httpRequest.getSession().getAttribute(Constant.USER_SESSION_KEY);
		if (user == null) {
			String code = httpRequest.getParameter(Constant.CODE_KEY);
			if (code != null) {
				logger.info("code info : "+code);
				/**
				 * 通过code，appid及secret获取当前登录cloudlink的帐号信息
				 */
				User currentUser = freeAccessHelper.getUser(code);
				if (currentUser != null) {
					 /**
					  * 根据企业系统内部的映射关系，获取当前帐号在企业内部的帐号ID，构建业务系统的用户登录信息
					  * 本demo为演示，直接使用 cloudlink中的用户信息
					  */
					httpRequest.getSession().setAttribute(Constant.USER_SESSION_KEY, currentUser);
					filterChain.doFilter(servletRequest, servletResponse);
				}

			} else {
				user = new User();
				user.setUserId("xiaoming");
				user.setUserName("小明");
				httpRequest.getSession().setAttribute(Constant.USER_SESSION_KEY, user);
				filterChain.doFilter(servletRequest, servletResponse);
				// 根据具体业务，返回登录页面或报错提示

			}
		} else {
			filterChain.doFilter(servletRequest, servletResponse);
		}

	}

	public void destroy() {

	}
}
