package com.cloudlink.open.service.impl;

import java.util.ArrayList;
import java.util.List;
import java.util.UUID;

import org.apache.commons.lang3.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import com.cloudlink.open.bo.LeaveBO;
import com.cloudlink.open.common.StateNum;
import com.cloudlink.open.dao.LeaveDAO;
import com.cloudlink.open.model.LeaveModel;
import com.cloudlink.open.service.LeaveService;
import com.cloudlink.open.util.TimeUtil;
import com.cloudlink.open.vo.LeaveApproveVO;

 /**
  * 业务层
  * @author Administrator
  *
  */
@Service("leaveService")
public class LeaveServiceImpl implements LeaveService {
	@Autowired
	private LeaveDAO leaveDAO;
	private static final Logger logger = LoggerFactory.getLogger(LeaveService.class);

	/**
	 * 新增保存请假单
	 */
	public void saveLeave(LeaveBO bo) {
		LeaveModel leaveModel = new LeaveModel();
		BeanUtils.copyProperties(bo, leaveModel);
		if (StringUtils.isBlank(bo.getId())) {

			leaveModel.setId(UUID.randomUUID().toString());
			leaveModel.setStateKey(StateNum.APPROVAL.getIndex());
			leaveModel.setStateValue(StateNum.APPROVAL.getName());
		}
		leaveModel.setCreateTime(TimeUtil.getCuttentTime());
		leaveDAO.save(leaveModel);

	}
	/**
	 * 更新请假单
	 */
	public void updateLeave(LeaveApproveVO leaveVo) {
		LeaveModel model = this.leaveDAO.getOne(leaveVo.getId());
		if (leaveVo.getApproveResult() == 1) {
			model.setStateKey(StateNum.FINASH.getIndex());
			model.setStateValue(StateNum.FINASH.getName());
		} else {
			model.setStateKey(StateNum.REJECTION.getIndex());
			model.setStateValue(StateNum.REJECTION.getName());
		}
		model.setApproveComment(leaveVo.getApproveComment());
		leaveDAO.save(model);

	}

	/**
	 * 查询个人请假列表
	 */
	public List<LeaveBO> getMyList(String uid, int stateKey) {
		logger.info("uid:" + uid + ",stateKey:" + stateKey);
		List<LeaveBO> boList = new ArrayList<LeaveBO>();
		List<LeaveModel> modelList = null;
		if (stateKey == 3) {
			modelList = this.leaveDAO.findByApplyUserId(uid);
		} else {
			modelList = this.leaveDAO.findByApplyUserIdAndStateKey(uid, stateKey);
		}

		if (modelList != null) {
			for (LeaveModel model : modelList) {
				LeaveBO bo = new LeaveBO();
				BeanUtils.copyProperties(model, bo);
				boList.add(bo);
			}
		} else {
			logger.info("getMyList modelList is null");
		}

		return boList;
	}

	/**
	 * 查询审批列表
	 */
	public List<LeaveBO> getApproveList(String leaderId, int stateKey) {
		logger.info("leaderId:" + leaderId + ",stateKey:" + stateKey);
		List<LeaveBO> boList = new ArrayList<LeaveBO>();
		List<LeaveModel> modelList = null;
		if (stateKey == 3) {
			modelList = this.leaveDAO.findByLeaderId(leaderId);
		}
		modelList = this.leaveDAO.findByLeaderIdAndStateKey(leaderId, stateKey);
		if (modelList != null) {
			for (LeaveModel model : modelList) {
				LeaveBO bo = new LeaveBO();
				BeanUtils.copyProperties(model, bo);
				boList.add(bo);
			}
		} else {
			logger.info("getApproveList modelList is null");
		}

		return boList;
	}

	/**
	 * 查询请假单详情
	 */
	public LeaveBO getLeave(String id) {
		LeaveBO bo = new LeaveBO();
		logger.info("Receive get leave request id:" + id);
		LeaveModel model = this.leaveDAO.findOne(id);
		if (model != null) {
			BeanUtils.copyProperties(model, bo);
		}
		return bo;
	}

	/**
	 * 查询草稿列表
	 */
	public List<LeaveBO> getDraftLeaveList(String uid) {
		List<LeaveBO> boList = new ArrayList<LeaveBO>();
		List<LeaveModel> modelList = this.leaveDAO.findDraft(uid);
		for (LeaveModel model : modelList) {
			LeaveBO bo = new LeaveBO();
			BeanUtils.copyProperties(model, bo);
			boList.add(bo);
		}
		return boList;
	}
}
